@@ -121,10 +121,8 @@ class KismetRtlamr(object):
 
         parser = argparse.ArgumentParser(description='RTL-SDR amr to Kismet bridge - Creates a rtlamr data source on a Kismet server and passes JSON-based records from the rtlamr binary')
         
-        parser.add_argument('--in-fd', action="store", type=int, dest="infd")
-        parser.add_argument('--out-fd', action="store", type=int, dest="outfd")
-        parser.add_argument('--connect', action="store", dest="connect")
-        parser.add_argument("--source", action="store", dest="source")
+        # Append the default args
+        parser = kismetexternal.ExternalInterface.common_getopt(parser)
         
         self.config = parser.parse_args()
 
@@ -142,7 +140,7 @@ class KismetRtlamr(object):
             self.proberet = self.datasource_probesource(source, options)
 
             if self.proberet == None:
-                print("Could not configure local source {}, check your source options and config.")
+                print(f"Could not configure local source {config.source}, check your source options and config.")
                 sys.exit(0)
 
             if not "success" in self.proberet:
@@ -160,7 +158,7 @@ class KismetRtlamr(object):
             print("Connecting to remote server {}".format(self.config.connect))
 
     def run(self):
-        self.kismet = kismetexternal.Datasource(self.config.infd, self.config.outfd, remote = self.config.connect)
+        self.kismet = kismetexternal.Datasource(self.config)
 
         self.kismet.set_configsource_cb(self.datasource_configure)
         self.kismet.set_listinterfaces_cb(self.datasource_listinterfaces)
@@ -216,7 +214,8 @@ class KismetRtlamr(object):
                     dev_index = serial
 
                 intf = kismetexternal.datasource_pb2.SubInterface()
-                intf.interface = "rtlamr-{}".format(dev_index)
+                intf.interface = f"rtlamr-{dev_index}"
+                intf.capinterface = f"rtl-{dev_index}"
                 intf.flags = ""
                 intf.hardware = self.rtlsdr.rtl_get_device_name(i)
                 interfaces.append(intf)
@@ -238,29 +237,26 @@ class KismetRtlamr(object):
         # Device selector could be integer position, or it could be a serial number
         devselector = source[7:]
         found_interface = False
+
         intnum = -1
 
+        # Try it as a serial number; try this first to deal with serial numbers like 00000000001
+        intnum = self.rtlsdr.rtl_get_index_by_serial(devselector.encode('utf-8'))
+
         # Try to find the device as an index
-        try:
-            intnum = int(devselector)
+        if intnum < 0:
+            try:
+                intnum = int(devselector)
 
-            # Abort if we're not w/in the range
-            if intnum >= self.rtlsdr.rtl_get_device_count():
-                raise ValueError("n/a")
+                # Abort if we're not w/in the range
+                if intnum >= self.rtlsdr.rtl_get_device_count():
+                    raise ValueError("n/a")
 
-            # Otherwise we've found a device
-            found_interface = True
-
-        except ValueError:
-            # A value error means we just need to look at it as a device num
-            pass
-        except:
-            # Otherwise something failed in querying the hw at a deeper level
-            return None
-
-        # Try it as a serial number
-        if not found_interface:
-            intnum = self.rtlsdr.rtl_get_index_by_serial(devselector.encode('utf-8'))
+            except ValueError:
+                intnum = -1
+            except:
+                # Otherwise something failed in querying the hw at a deeper level
+                return None
 
         # We've failed as both a serial and as an index, give up
         if intnum < 0:
@@ -281,7 +277,7 @@ class KismetRtlamr(object):
         ret = {}
 
         # Does the source look like 'rtlamr-XYZ'?
-        if not source[:7] == "rtlamr-":
+        if not source[:7] == "rtlamr-" and not source[:4] == "rtl-":
             ret["success"] = False
             ret["message"] = "Could not parse which rtlsdr device to use"
             return ret
@@ -351,6 +347,8 @@ class KismetRtlamr(object):
         else:
             ret['uuid'] = self.__get_rtlsdr_uuid(intnum)
 
+        ret['capture_interface'] = f"rtl-{devselector}"
+
         self.opts['device'] = intnum
 
         ret['success'] = True
@@ -392,7 +390,13 @@ class KismetRtlamr(object):
 
     def __async_radio_thread(self):
         # This function blocks forever until cancelled
-        self.rtlsdr.read_samples(self.rtl_data_cb, 12, self.usb_buf_sz)
+        try:
+            self.rtlsdr.read_samples(self.rtl_data_cb, 12, self.usb_buf_sz)
+        except rtlsdr.RadioOperationalError as e:
+            if not self.kismet.inSpindown():
+                self.kismet.send_datasource_error_report(message = f"Error reading from RTLSDR: {e}")
+        except Exception as e:
+            self.kismet.send_datasource_error_report(message = f"Error reading from RTLSDR: {e}")
 
         # Always make sure we die
         self.kill_amr()
@@ -445,6 +449,9 @@ class KismetRtlamr(object):
             return
 
     def rtl_data_cb(self, buf, buflen, ctx):
+        if buflen == 0:
+            raise RuntimeError("received empty data from rtlsdr")
+
         nb = np.ctypeslib.as_array(buf, shape=(buflen,)).astype(np.uint8)
         self.process(nb)
         return 
